// Copyright (c) 2015, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

library test.source;

import 'caching_put_package_map_provider_test.dart' as caching_provider_test;

/// Utility for manually running all tests.
main() {
  caching_provider_test.main();
}
